@@ -4,8 +4,5 @@ then
     /usr/bin/cp /etc/defaults/etc/vimrc /etc/vimrc
 fi
 
-if [ -x /usr/bin/gtk-update-icon-cache.exe ]
-then
-    /usr/bin/gtk-update-icon-cache --force /usr/share/icons/hicolor
-fi
-
+rm -f /usr/share/icons/hicolor/icon-theme.cache
+rm -f /usr/share/icons/locolor/icon-theme.cache
